==> tivio_sdk-1.0.0.tar.gz: lib/player/tivio_player_wrapper.dart <==
import '../bridge.dart';
import '../player/tivio_player_input_source.dart';
import '../utils/enum.dart';
import '../logger.dart';
import '../enums/tivio_player_state.dart';

class TivioPlayerWrapperController {
  final Function play;
  final Function pause;
  final Function seekTo;
  final Function openAndPlay;

  TivioPlayerWrapperController(
    this.play,
    this.pause,
    this.seekTo,
    this.openAndPlay,
  );
}

class TivioPlayerWrapper {
  final String id;
  final Bridge _bridge;
  final Logger _logger = Logger();

  TivioPlayerWrapper(this.id, this._bridge);

  register(TivioPlayerWrapperController controller) async {
    await _bridge.playerRegister(this.id);

    _bridge.onPlayerPlay(
      id,
      controller.play,
    );

    _bridge.onPlayerPause(
      id,
      controller.pause,
    );

    _bridge.onPlayerSeekTo(
      id,
      (payload) {
        print(payload);
        return controller.seekTo(
          Duration(
            milliseconds: payload['timestampMs'],
          ),
        );
      },
    );

    _bridge.onPlayerChangeSource(
      id,
      (payload) {
        _logger.verbose(payload);
        String sourceType = payload['source']['type'];
        switch (sourceType) {
          case 'vod_tivio':
            {
              controller.openAndPlay(
                TivioPlayerVodSource.fromDynamic(payload['source']),
                currentTime: payload['source']['currentTime'],
              );
            }
            break;
          case 'advertisement':
            {
              controller.openAndPlay(TivioPlayerAdSource.fromDynamic(payload['source']));
            }
            break;
          default:
            {
              throw Exception('Unknown source type $sourceType');
            }
        }
      },
    );
  }

  play() {
    return _bridge.playerPlay(id);
  }

  pause() {
    return _bridge.playerPause(id);
  }

  openAndPlay(TivioPlayerInputSource source) {
    return _bridge.playerOnSourceChanged(
      id,
      source.toObject(),
    );
  }

  seekTo(Duration time) {
    return _bridge.playerSeekTo(id, time.inMilliseconds);
  }

  onTimeChanged(Duration time) {
    return _bridge.playerOnTimeChanged(id, time.inMilliseconds);
  }

  onStateChanged(TivioPlayerState state) {
    return _bridge.playerOnStateChanged(id, enumToString(state));
  }

  onPlaybackEnded() {
    return _bridge.onPlaybackEnded(id);
  }

  skipAd() {
    return _bridge.playerSkipAd(id);
  }
}

==> tivio_sdk-1.2.0.tar.gz: lib/player/tivio_player_wrapper.dart <==
import '../bridge.dart';
import '../player/tivio_player_input_source.dart';
import '../utils/enum.dart';
import '../logger.dart';
import '../enums/tivio_player_state.dart';

class TivioPlayerWrapperController {
  final Function play;
  final Function pause;
  final Function seekTo;
  final Function openAndPlay;

  TivioPlayerWrapperController(
    this.play,
    this.pause,
    this.seekTo,
    this.openAndPlay,
  );
}

class TivioPlayerWrapper {
  final String id;
  final Bridge _bridge;
  final Logger _logger = Logger();

  TivioPlayerWrapper(this.id, this._bridge);

  register(TivioPlayerWrapperController controller) async {
    await _bridge.playerRegister(this.id);

    _bridge.onPlayerPlay(
      id,
      controller.play,
    );

    _bridge.onPlayerPause(
      id,
      controller.pause,
    );

    _bridge.onPlayerSeekTo(
      id,
      (payload) {
        print(payload);
        return controller.seekTo(
          Duration(
            milliseconds: payload['timestampMs'],
          ),
        );
      },
    );

    _bridge.onPlayerChangeSource(
      id,
      (payload) {
        _logger.verbose(payload);
        String? sourceType = payload['source']['type'];
        switch (sourceType) {
          case 'vod_tivio':
            {
              controller.openAndPlay(
                TivioPlayerVodSource.fromJson(payload['source']),
                currentTime: payload['source']['currentTime'],
              );
            }
            break;
          case 'advertisement':
            {
              controller.openAndPlay(TivioPlayerAdSource.fromJson(payload['source']));
            }
            break;
          default:
            {
              throw Exception('Unknown source type $sourceType');
            }
        }
      },
    );
  }

  play() {
    return _bridge.playerPlay(id);
  }

  pause() {
    return _bridge.playerPause(id);
  }

  openAndPlay(TivioPlayerInputSource source) {
    return _bridge.playerOnSourceChanged(
      id,
      source.toObject(),
    );
  }

  seekTo(Duration time) {
    return _bridge.playerSeekTo(id, time.inMilliseconds);
  }

  onTimeChanged(Duration time) {
    return _bridge.playerOnTimeChanged(id, time.inMilliseconds);
  }

  onStateChanged(TivioPlayerState state) {
    return _bridge.playerOnStateChanged(id, enumToString(state));
  }

  onPlaybackEnded() {
    return _bridge.onPlaybackEnded(id);
  }

  skipAd() {
    return _bridge.playerSkipAd(id);
  }
}
